USE [NIKU]
GO

/****** Object:  View [niku].[DWH_X_RES_AVAIL_PER_FACTS_V]    Script Date: 15/09/2017 12:04:21 ******/
SET ANSI_NULLS ON
GO

SET QUOTED_IDENTIFIER ON
GO

CREATE 
VIEW [niku].[DWH_X_RES_AVAIL_PER_FACTS_V]
AS
       WITH slice_range (from_date, row_count) AS
               (SELECT MIN(from_date) from_date,
                       MAX(num_periods) row_count
                FROM   prj_blb_slicerequests
                WHERE  is_dwh_request = 1
                AND    1 = (SELECT fiscal_slices FROM dwh_settings)
                AND    request_name = 'resource::pravailcurve::dwh_fiscal'),
               
            fiscal_periods (period_key, period_start, row_key) AS
              (SELECT d.period_key,
                      d.period_start,
                      d.row_key
               FROM  (SELECT p.id period_key,
                             p.start_date period_start,
                             r.row_count,
                             ROW_NUMBER() OVER (PARTITION BY p.entity_id ORDER BY p.start_date) AS row_key
                      FROM   biz_com_periods p,
                             dwh_settings s,
                             slice_range r
                      WHERE  p.entity_id = s.entity_key
                      AND    p.period_type IN ('MONTHLY','13_PERIODS_PER_YEAR')
                      AND    p.start_date >= r.from_date) d
               WHERE  d.row_key <= d.row_count),
               
            cal_slice_keys (request_key, period_type) AS
               (SELECT id request_key,
                       CASE WHEN period = 1 THEN 'WEEKLY' ELSE 'MONTHLY' END period_type 
                FROM   prj_blb_slicerequests
                WHERE  is_dwh_request = 1 
                AND  (((SELECT monthly_slices FROM dwh_settings) = 1
                AND    request_name = 'MONTHLYRESOURCEAVAILCURVE')
                OR   ((SELECT weekly_slices FROM dwh_settings) = 1
                AND    request_name = 'WEEKLYRESOURCEAVAILCURVE'))),
				
            fiscal_slice_key AS
               (SELECT id request_key, period period_type
                FROM   prj_blb_slicerequests
                WHERE  is_dwh_request = 1
                AND   (SELECT fiscal_slices FROM dwh_settings) = 1
                AND    request_name = 'resource::pravailcurve::dwh_fiscal'),

          avail_curves (resource_key, period_key, slice, created_date) AS
              (SELECT s.prj_object_id resource_key,
                      CASE WHEN sk.period_type = 'WEEKLY' THEN CAST(DATEDIFF(d,CONVERT(DATETIME,'01/01/2000',101),s.slice_date) + 2000000 AS INTEGER)
                           ELSE CAST(DATEDIFF(d,CONVERT(DATETIME,'01/01/2000',101),s.slice_date) + 3000000 AS INTEGER) END period_key,
                      s.slice,
                      s.created_date
               FROM   prj_blb_slices s,
                      cal_slice_keys sk,
                      rpt_calendar c
               WHERE  s.slice_request_id = sk.request_key
               AND    sk.period_type = c.period_type
               AND    s.slice_date = c.start_date
               AND    s.slice <> 0
               UNION ALL
               SELECT s.prj_object_id resource_key,
                      fp.period_key,
                      s.slice,
                      s.created_date
               FROM   prj_fiscal_blb_slices s,
                      fiscal_slice_key sk,
                      fiscal_periods fp                   
               WHERE  s.slice_request_id = sk.request_key
               AND    s.period_id = fp.period_key
               AND    s.slice <> 0)

SELECT A.RESOURCE_KEY,
       A.PERIOD_KEY,
       ISNULL(A.SLICE,0) AVAIL_HOURS,
       A.CREATED_DATE SLICE_CREATED_DATE
FROM   avail_curves a
GO


